=====
About
=====

tg-pubsub provides easy pubsub for django models using redis messaging queue

Features
--------

* Can mark own models as listenable
* Can mark external models as listenable
* Builtin pubsub server
